==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Effect/srconverter/translations/srconverter_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="cs">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="30"/>
        <source>SRC Plugin</source>
        <translation>Modul SRC</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="49"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>O modulu SRC</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="50"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Modul Qmmp pro konverzi vzorkovací frekvence</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="51"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Nastavení modulu SRC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Sample Rate (Hz):</source>
        <translation>Vzorkovací frekvence (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Interpolation Engine:</source>
        <translation>Způsob interpolace:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Best Sinc Interpolation</source>
        <translation>Nejlepší interpolace pomocí sinc</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Medium Sinc Interpolation</source>
        <translation>Střední interpolace pomocí sinc</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>Nejrychlejší interpolace pomocí sinc</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>ZOH Interpolation</source>
        <translation>Interpolace ZOH</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Linear Interpolation</source>
        <translation>Lineární interpolace</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Effect/srconverter/translations/srconverter_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="30"/>
        <source>SRC Plugin</source>
        <translation>Modul SRC</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="50"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>O modulu SRC</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="51"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Modul Qmmp pro konverzi vzorkovací frekvence</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Nastavení modulu SRC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Sample Rate (Hz):</source>
        <translation>Vzorkovací frekvence (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Interpolation Engine:</source>
        <translation>Způsob interpolace:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Best Sinc Interpolation</source>
        <translation>Nejlepší interpolace pomocí sinc</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Medium Sinc Interpolation</source>
        <translation>Střední interpolace pomocí sinc</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>Nejrychlejší interpolace pomocí sinc</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>ZOH Interpolation</source>
        <translation>Interpolace ZOH</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Linear Interpolation</source>
        <translation>Lineární interpolace</translation>
    </message>
</context>
</TS>
